@@ -6,7 +6,7 @@ void Generator::idOfTag(ostream &out) const
 
     if (d_options.tagMismatches().value == Options::ON)
     {
-        out << "char const *idOfTag__[] = {\n";
+        out << "char const *idOfTag_[] = {\n";
         for (auto const &poly: d_polymorphic)
             out << "    \"" << poly.first << "\",\n";
         out <<     "    \"<undefined>\"\n"
