@@ -24,7 +24,7 @@ void Generator::polymorphicSpecializations(ostream &out) const
             "template <>\n"
             "struct TypeOf<Tag_::" << poly.first << ">\n"
             "{\n"
-            "    typedef " << poly.second << " type;\n"
+            "    using type = " << poly.second << ";\n"
             "};\n"
             "\n";
 }
