@@ -29,8 +29,8 @@ class Item
     static std::ostream &(Item::*s_insertPtr)(std::ostream &out) const;
     
     public:
-        typedef std::vector<Item>                   Vector;
-        typedef std::vector<Item>::const_iterator   ConstIter;
+        using Vector = std::vector<Item>;
+        using ConstIter = std::vector<Item>::const_iterator;
 
         Item();
 
