@@ -6,7 +6,7 @@ void Options::setStype()
         return;
 
     if (d_matched->find(';') == string::npos)
-        d_stackDecl = "typedef " + *d_matched + " STYPE_;\n";
+        d_stackDecl = "using STYPE_ = " + *d_matched + ";\n";
     else
         emsg << "`;' in %stype type-definition `" << *d_matched << '\'' << 
                 endl;
