@@ -24,9 +24,9 @@ namespace FBB
 class Parser: public ParserBase
 {
             // actions to taken given tokens returned by the lexical scanner
-    typedef std::unordered_map<size_t, void (Parser::*)()>  ActionMap;
-    typedef ActionMap::iterator                             Iterator;
-    typedef ActionMap::value_type                           Value;
+    using ActionMap = std::unordered_map<size_t, void (Parser::*)()>;
+    using Iterator = ActionMap::iterator;
+    using Value = ActionMap::value_type;
 
     enum SemType        // s_autoTypeLable must be synchronized with this
     {                   // enum
@@ -60,12 +60,12 @@ class Parser: public ParserBase
     SemType     d_semType = SINGLE;     // see set{union,polymorphic}decl.cc
 
         // ADfun: pointer to member function handling @ and $ constructions
-    typedef bool (Parser::*ADfun)
+    using ADfun = bool (Parser::*)
                         (int nElements, Block &block, AtDollar const &atd);
 
         // ADmap: unordered map returning a function given an 
         //                                              AtDollar::Pattern
-    typedef std::unordered_map<int, ADfun> ADmap;
+    using ADmap = std::unordered_map<int, ADfun>;
 
     ADmap *d_atDollar = &s_single;
 
@@ -99,7 +99,7 @@ class Parser: public ParserBase
     static ADmap s_union;
     static ADmap s_polymorphic;
 
-    typedef void (Parser::*ActionBlockInstaller)(std::string const &ruleType, 
+    using ActionBlockInstaller = void (Parser::*)(std::string const &ruleType, 
                                                  Production const &prod);
 
     static ActionBlockInstaller s_defaultAction[2][3][3];
