@@ -19,7 +19,7 @@
 
 class Production: private std::vector<Symbol *>
 {
-    typedef std::vector<Symbol *> Inherit;
+    using Inherit = std::vector<Symbol *>;
 
     friend std::ostream &operator<<(std::ostream &out, 
                                                Production const *production);
@@ -65,9 +65,9 @@ class Production: private std::vector<Symbol *>
         using Inherit::rend;
         using Inherit::push_back;
 
-        typedef std::vector<Production *>       Vector;
-        typedef std::vector<Production const*>  ConstVector;
-        typedef ConstVector::const_iterator     ConstIter;
+        using Vector = std::vector<Production *>;
+        using ConstVector = std::vector<Production const*>;
+        using ConstIter = ConstVector::const_iterator;
 
         Production(Symbol const *nonTerminal, size_t lineNr);
 
