@@ -9,8 +9,8 @@ class Symbol;
 class RmReduction
 {
     public:
-        typedef std::vector<RmReduction>    Vector;
-        typedef Vector::const_iterator      ConstIter;
+        using Vector = std::vector<RmReduction>;
+        using ConstIter = Vector::const_iterator;
 
     private:
         size_t  d_idx;              // idx in a StateItem::Vector of
