@@ -30,7 +30,7 @@ class Rules
             // definitions rather than as alternatives. There's nothing
             // inherently wrong with that, but it may also be a typo causing
             // unexpected conflicts
-        typedef std::pair<std::string, size_t> FileInfo;
+        using FileInfo = std::pair<std::string, size_t>;
 
         //FBB: 20160412 - see also sethiddenaction.cc for the use
         //                of the 90000 line number flag that was used to flag
@@ -38,8 +38,8 @@ class Rules
         //                so I decided not to use it anymore.
 
     private:
-        typedef std::unordered_map<NonTerminal const *, FileInfo> 
-                                                            NFileInfoMap;
+        using NFileInfoMap = 
+                        std::unordered_map<NonTerminal const *, FileInfo>;
     
         Terminal::Vector d_terminal;        // the vector holding information 
                                             // about defined terminal symbols
