@@ -8,7 +8,7 @@
 void SRConflict::handleSRconflict(Next::ConstIter const &next, 
                                   size_t reducibleItemIdx)
 {
-    typedef Enum::Solution Solution;
+    using Solution = Enum::Solution;
 
     StateItem::Vector const &itemVector = d_itemVector;
     Symbol const *precedence = itemVector[reducibleItemIdx].precedence();
