@@ -17,10 +17,10 @@ class Rules;
 
 class State
 {
-    typedef std::vector<State *> Vector;
+    using Vector = std::vector<State *>;
     
     public:
-        typedef Vector::const_iterator  ConstIter;
+        using ConstIter = Vector::const_iterator;
 
     private:
         friend std::ostream &operator<<(std::ostream &out, 
