@@ -33,8 +33,8 @@ class StateItem
     static std::ostream &(StateItem::*s_insertPtr)(std::ostream &out) const;
 
     public:
-        typedef std::vector<StateItem> Vector;
-        typedef Vector::const_iterator ConstIter;
+        using Vector = std::vector<StateItem>;
+        using ConstIter = Vector::const_iterator;
 
         StateItem();
         StateItem(Item const &item);
