@@ -10,7 +10,7 @@
 class Symbol: public Element
 {
     public:
-        typedef std::vector<Symbol const *>  Vector;
+        using Vector = std::vector<Symbol const *>;
     
         enum Type
         {
